/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package pushwithreturn;

import java.util.Collections;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.PushWithReturn;
import org.objectweb.dream.control.activity.Util;
import org.objectweb.dream.control.activity.task.AbstractTask;
import org.objectweb.dream.control.activity.task.Task;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.MessageType;
import org.objectweb.dream.message.MessageTypeImpl;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Implementation of the Producer component.
 */
public class ProducerImpl extends AbstractComponent
{

  PushWithReturn outPushWithReturnItf;
  MessageManager messageManagerItf;
  MessageType    msgType = new MessageTypeImpl(TestChunk.DEFAULT_NAME,
                             TestChunk.TYPE);

  Task           tasks;

  // -------------------------------------------------------------------------
  // Overriden methods
  // -------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.AbstractComponent#beforeFirstStart(org.objectweb.fractal.api.Component)
   */
  protected void beforeFirstStart(Component componentItf)
      throws IllegalLifeCycleException
  {
    try
    {
      Util.addTask(componentItf, new ProducerTask("Producer task"),
          Collections.EMPTY_MAP);
      logger.log(BasicLevel.DEBUG, "task added");
    }
    catch (Exception e)
    {
      throw new IllegalLifeCycleException("Can't add task");
    }
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(PushWithReturn.OUT_PUSH_WITH_RETURN_ITF_NAME))
    {
      outPushWithReturnItf = (PushWithReturn) serverItf;
    }
    else if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{PushWithReturn.OUT_PUSH_WITH_RETURN_ITF_NAME,
        MessageManager.ITF_NAME};
  }

  private class ProducerTask extends AbstractTask
  {

    private String message = "Producer";

    /**
     * Constructor
     */
    public ProducerTask(String name)
    {
      super(name);
    }

    /**
     * @see Task#execute(Object)
     */
    public Object execute(Object hints) throws InterruptedException
    {
      try
      {
        Message msg = messageManagerItf.createMessage(msgType);
        TestChunk chunk = (TestChunk) msg.getChunk(TestChunk.DEFAULT_NAME);
        chunk.setMessage(message);
        logger.log(BasicLevel.INFO, "Producer sends message " + msg);
        Message returnMessage = outPushWithReturnItf.pushWithReturn(msg, null);
        logger.log(BasicLevel.INFO, "Producer receives return message "
            + returnMessage);
      }
      catch (Exception e)
      {
        e.printStackTrace();
        return STOP_EXECUTING;
      }
      Thread.sleep(1000);
      return EXECUTE_AGAIN;
    }
  }

}