/**
 * Dream
 * Copyright (C) 2003 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: vivien.quema@inrialpes.fr
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package utobcast;

import java.net.InetAddress;

import org.objectweb.dream.protocol.ProcessImpl;

/**
 * This class implements a TCP process. Such a process is remotely accessible
 * using a TCP channel. It is identified by an IP address and a port number.
 */
public class TCPProcess extends ProcessImpl
{

  // IP address
  private InetAddress inetAddr;

  // port number
  private int         port;

  // ---------------------------------------------------------------------------
  // Constructor.
  // ---------------------------------------------------------------------------

  /**
   * Allocates a new TCPProcess object.
   * 
   * @param id the identifier of the process.
   * @param inetAddr the inet address of the process.
   * @param port of the process.
   */
  public TCPProcess(short id, InetAddress inetAddr, int port)
  {
    super(id);
    this.inetAddr = inetAddr;
    this.port = port;

  }

  // ---------------------------------------------------------------------------
  // Methods.
  // ---------------------------------------------------------------------------

  /**
   * Returns the inet address of the process.
   * 
   * @return the inet address of the process.
   */
  public InetAddress getInetAddress()
  {
    return inetAddr;
  }

  /**
   * Returns the port of the process.
   * 
   * @return the port of the process.
   */
  public int getPort()
  {
    return port;
  }
}