/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package utobcast.draw;

import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.message.ChunkTypeImpl;

/**
 * Chunk interface for Draw example messages. This interface allows
 * setting/retrieving a DrawCommand object.
 * 
 * @see utobcast.draw.DrawCommand
 */
public interface DrawCommandChunk
{
  /** The default name for chunks of this type. */
  String    DEFAULT_NAME = "drawCommandChunk";

  /** The Chunk type of chunks that implements this interface. */
  ChunkType TYPE         = new ChunkTypeImpl(DrawCommandChunk.class,
                             DrawCommandChunkImpl.class);

  /**
   * Returns the DrawCommand object contained in this chunk.
   * 
   * @return the DrawCommand object contained in this chunk.
   */
  DrawCommand getDrawCommand();

  /**
   * Sets the DrawCommand object contained in this chunk.
   * 
   * @param dc the DrawCommand object contained in this chunk.
   */
  void setDrawCommand(DrawCommand dc);

}