/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.channel;

import java.io.IOException;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * A opened socket manager for mono connection Channel. This component simply
 * forward opened sockets then close them.
 */
public class OpenedSocketManagerMonoNotPersistentImpl extends AbstractComponent
    implements
      OpenedSocket
{

  // ---------------------------------------------------------------------------
  // Client interfaces
  // ---------------------------------------------------------------------------

  protected OpenedSocket delegateOpenedSocketItf;

  // ---------------------------------------------------------------------------
  // Implementation of OpenedSocket interface
  // ---------------------------------------------------------------------------

  /**
   * @see OpenedSocket#openedSocket(SocketState)
   */
  public void openedSocket(SocketState socket) throws IOException,
      InterruptedException
  {
    delegateOpenedSocketItf.openedSocket(socket);
    socket.close();
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{OpenedSocket.ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(OpenedSocket.ITF_NAME))
    {
      delegateOpenedSocketItf = (OpenedSocket) serverItf;
    }
  }
}