/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import java.io.IOException;

import org.objectweb.dream.message.Message;

/**
 * Interface used by ChannelOut to retreive a socket to send a message to a
 * ChannelIn.
 */
public interface SocketManager
{
  /** The default name of interface of this type. */
  String ITF_NAME = "socket-manager";

  /**
   * Returns a socket that can be used to send message to a ChannelIn
   * 
   * @param message a message that is going to be sent to a ChannelIn
   * @return a connection to the ChannelIn.
   * @throws IOException if the socket can't be opened.
   * @throws InterruptedException if the component is interrupted while waiting.
   */
  SocketState getSocket(Message message) throws IOException,
      InterruptedException;

  /**
   * Releases the given {@link SocketState }.
   * 
   * @param socketState the socket state to release.
   * @param error <code>true</code> if an exception has been catched while
   *          sending the message, <code>false</code> otherwise.
   */
  void releaseSocket(SocketState socketState, boolean error);
}