/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.protocol;

import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.message.ChunkTypeImpl;

/**
 * A general purpose chunk that can be use to identify the sender and receiver
 * processes of a message. Note that a process is identified using a short
 * integer.
 * 
 * @see Process
 */
public interface ArrowChunk
{

  /** The default name for chunks of this type */
  String    DEFAULT_NAME = "arrowChunk";

  /** The chunk type of chunks implementing this interface. */
  ChunkType TYPE         = new ChunkTypeImpl(ArrowChunk.class,
                             ArrowChunkImpl.class);

  /**
   * Returns the identifier of the sender process.
   * 
   * @return the identifier of the sender process.
   */
  short getProcessIdFrom();

  /**
   * Sets the identifier of the sender process.
   * 
   * @param from the identifier of the sender process.
   */
  void setProcessIdFrom(short from);

  /**
   * Returns the identifier of the receiver process.
   * 
   * @return the identifier of the receiver process.
   */
  short getProcessIdTo();

  /**
   * Sets the identifier of the receiver process.
   * 
   * @param to the identifier of the receiver process.
   */
  void setProcessIdTo(short to);
}