/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.protocol.utobcast.message;

import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.message.ChunkTypeImpl;
import org.objectweb.dream.protocol.Process;

/**
 * Chunk interface for UPD messages. An UPD message contains the information
 * sent from the new leader to the process chosen for becoming the new backup.
 */
public interface UPDChunk
{
  /** The default name for chunks of this type. */
  String    DEFAULT_NAME = "updChunk";

  /** The Chunk type of chunks that implements this interface. */
  ChunkType TYPE         = new ChunkTypeImpl(UPDChunk.class, UPDChunkImpl.class);

  /**
   * Returns the process array that is exchanged between the leader and the
   * backup.
   * 
   * @return a process array.
   */
  Process[] getProcesses();

  /**
   * Sets the process array that is exchanged between the leader and the backup.
   * 
   * @param processes the process array to be set.
   */
  void setProcesses(Process[] processes);

  /**
   * Returns the sequence number that is exchanged between the leader and the
   * backup.
   * 
   * @return the sequence number.
   */
  long getSequenceNumber();

  /**
   * Sets the sequence number that is exchanged between the leader and the
   * backup.
   * 
   * @param sn the sequence number to be set.
   */
  void setSequenceNumber(long sn);

}