/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.utobcast.message;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.protocol.Process;

/**
 * Basic implementation of the {@link UPDChunk}interface.
 */
public class UPDChunkImpl extends AbstractChunk implements UPDChunk
{
  /** The process array. */
  protected Process[] processes;

  /** The sequence number of this message. */
  protected long      sn = -1;

  // ---------------------------------------------------------------------------
  // Implementation of the UPDChunk interface
  // ---------------------------------------------------------------------------
  /**
   * @see org.objectweb.dream.protocol.utobcast.message.UPDChunk#setSequenceNumber(long)
   */
  public void setSequenceNumber(long sn)
  {
    this.sn = sn;
  }

  /**
   * @see org.objectweb.dream.protocol.utobcast.message.UPDChunk#getSequenceNumber()
   */
  public long getSequenceNumber()
  {
    return sn;
  }

  /**
   * @see org.objectweb.dream.protocol.utobcast.message.UPDChunk#getProcesses()
   */
  public Process[] getProcesses()
  {
    return processes;
  }

  /**
   * @see org.objectweb.dream.protocol.utobcast.message.UPDChunk#setProcesses(org.objectweb.dream.protocol.Process[])
   */
  public void setProcesses(Process[] processes)
  {
    this.processes = processes;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return TYPE;
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ((UPDChunk) newInstance).setProcesses(getProcesses());
    ((UPDChunk) newInstance).setSequenceNumber(getSequenceNumber());
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
    processes = null;
    sn = -1;
  }

}