/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.pushwithreturn;

import java.io.Serializable;

/**
 * This interface defines a Key. Keys are used by the
 * <code>PushWithReturn</code> protocol to identify messages.
 * <p>
 * A key can correspond to all possible keys. For detecting such a key, called
 * "AllKey" this interface defines the <code>isAll</code> method that returns
 * <code>true</code> if this is the case.
 * <p>
 * <i>Note: </i> keys must implement <code>equals</code> and
 * <code>hashcode</code> methods.
 */
public interface Key extends Serializable
{
  /**
   * Checks whether this key correspond to all possible keys generated by the
   * generator that made it.
   * 
   * @return <code>true</code> if this key correspond to all keys generated by
   *         the generator that made it.
   */
  boolean isAll();
}