/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.pushwithreturn;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.util.Util;

/**
 * Basic implementation of the {@link KeyChunk}interface.
 */
public class KeyChunkImpl extends AbstractChunk
    implements
      KeyChunk,
      Externalizable
{
  Key key = null;

  // ---------------------------------------------------------------------------
  // Implementation of the KeyChunk interface.
  // ---------------------------------------------------------------------------

  /**
   * @see KeyChunk#getKey()
   */
  public Key getKey()
  {
    return key;
  }

  /**
   * @see KeyChunk#setKey(Key)
   */
  public void setKey(Key key)
  {
    this.key = key;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface.
  // ---------------------------------------------------------------------------
  /**
   * @see org.objectweb.dream.message.Chunk#getType()
   */
  public ChunkType getType()
  {
    return TYPE;
  }

  /**
   * @see org.objectweb.dream.message.Chunk#transfertState(org.objectweb.dream.message.Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ((KeyChunk) newInstance).setKey(getKey());
  }

  /**
   * @see org.objectweb.dream.message.Chunk#recycle()
   */
  public void recycle()
  {
    key = null;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the serialization methods
  // ---------------------------------------------------------------------------

  /**
   * @see Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    key = (Key) Util.readObject(in);
  }

  /**
   * @see Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    Util.writeObject(out, key);
  }

}