/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.pushwithreturn;

import org.objectweb.dream.pool.Recyclable;

/**
 * Implementation of the <code>Key</code> interface that uses positive
 * integers.
 */
public class KeyInteger implements Key, Recyclable
{

  private boolean isAll = false;

  private int     key   = -1;

  // ---------------------------------------------------------------------------
  // Constructors.
  // ---------------------------------------------------------------------------

  /**
   * Constructor.
   * 
   * @param key the key.
   * @param isAll boolean indicating if this is an "AllKey".
   */
  public KeyInteger(int key, boolean isAll)
  {
    this.key = key;
    this.isAll = isAll;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Key interface.
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.pushwithreturn.Key#isAll()
   */
  public boolean isAll()
  {
    return isAll;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Recyclable interface.
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.pool.Recyclable#recycle()
   */
  public void recycle()
  {
    isAll = false;
    key = -1;
  }

  // ---------------------------------------------------------------------------
  // Overriden methods.
  // ---------------------------------------------------------------------------

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj)
  {
    return key == ((KeyInteger) obj).key;
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode()
  {
    return key;
  }
}