/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.queue;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller interface for Push/Pull queue. It defines the blocking
 * pull policy, which control the beavior when the queue is empty.
 * <ul>
 * <li>If <code>true</code>, the pull method block until a new message is
 * pushed or throw a {@link org.objectweb.dream.InterruptedPullException}.
 * </li>
 * <li>If <code>false</code> the pull method returns <code>null</code>.
 * </li>
 */
public interface PullQueueAttributeController extends AttributeController
{

  /**
   * Returns the blocking pull policy.
   * 
   * @return the blocking pull policy.
   */
  boolean getBlockingPull();

  /**
   * Sets the blocking pull policy.
   * 
   * @param blockingPull the blocking pull policy.
   */
  void setBlockingPull(boolean blockingPull);
}